<?php

namespace Litecms\Placement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Placement\Models\Placement;

class PlacementPolicy
{

    /**
     * Determine if the given user can view the placement.
     *
     * @param UserPolicy $user
     * @param Placement $placement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Placement $placement)
    {
        if ($user->canDo('placement.placement.view') && $user->isAdmin()) {
            return true;
        }

        return $placement->user_id == user_id() && $placement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a placement.
     *
     * @param UserPolicy $user
     * @param Placement $placement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('placement.placement.create');
    }

    /**
     * Determine if the given user can update the given placement.
     *
     * @param UserPolicy $user
     * @param Placement $placement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Placement $placement)
    {
        if ($user->canDo('placement.placement.edit') && $user->isAdmin()) {
            return true;
        }

        return $placement->user_id == user_id() && $placement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given placement.
     *
     * @param UserPolicy $user
     * @param Placement $placement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Placement $placement)
    {
        return $placement->user_id == user_id() && $placement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given placement.
     *
     * @param UserPolicy $user
     * @param Placement $placement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Placement $placement)
    {
        if ($user->canDo('placement.placement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given placement.
     *
     * @param UserPolicy $user
     * @param Placement $placement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Placement $placement)
    {
        if ($user->canDo('placement.placement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
